@@ -6,7 +6,7 @@
     c("parm_lib", "pdForm_lib", "labelunit_lib", "rv_lib", "scaling",
       "template_nonmem", "template_mrgsolve", "template_bm", "model_lib",
       "Action", "Center", "Covariate", "Flags", "Function", "Functional form",
-      "Initial", "Parameter", 'Stage', 'Step', "Type", "combo", "name"
+      "Initial", "SourceParam", "Parameter", 'Stage', 'Step', "Type", "combo", "name"
       )
   )
 
